require 'math/matrix'
require 'wireframe_objects'
require 'wireframe_functions'

--[[
usage:
move camera side to side, up/down, in/out:
    w,a,s,d,r,f    

rotate camera on it's own x,y,z axis:
    up, left, down, right, lshift, enter

]]--


function love.load()
  
  font = love.graphics.newFont("fonts/courierbold.ttf", 20)
  wireframe_objects_load()
  
  -- camera
  campos = vect:new(0, 0, 700)    -- cam position
  camlook = vect:new(0, 0, -1)    -- the direction the camera is loooking
  camera = camera:new(campos, camlook)
  
  -- rotation/velocity speeds
  cam_velocity_x = 1000
  cam_velocity_y = 1000
  cam_velocity_z = 1000
  cam_rotate = 0.03
  speed = 0.02
  framecount = 0
  
  
  
  -- an axis
  ax = vect:new(0, 0, 1)    -- an axis
  a  = vect:new(0, 0, 0)    -- a point that lies on that axis
  
  
  -- initialize the cube (x, y, z, length, width, height, camera object)
  cube1 = cube:new(0, 0, 0, 100, 100, 100, camera)
  cube1:scale(3)
  
  -- these don't matter unless you do:
  -- cube1.translate_draw_points = true
  -- and then you can move the cube around with keys i,j,k,l
  cube1.x = 400
  cube1.y = 300
  
end


function love.update(dt)
  framecount = framecount + 1

  -- translate camera
  if love.keyboard.isDown("d") then camera:move_x(-cam_velocity_x*dt) end
  if love.keyboard.isDown("a") then camera:move_x(cam_velocity_x*dt)  end
  if love.keyboard.isDown("w") then camera:move_y(cam_velocity_y*dt)  end
  if love.keyboard.isDown("s") then camera:move_y(-cam_velocity_y*dt) end
  if love.keyboard.isDown("r") then camera:move_z(cam_velocity_z*dt)  end
  if love.keyboard.isDown("f") then camera:move_z(-cam_velocity_z*dt) end
 
  
  -- rotate camera
  if love.keyboard.isDown("right")  then camera:rotate_y(cam_rotate)  end
  if love.keyboard.isDown("left")   then camera:rotate_y(-cam_rotate) end
  if love.keyboard.isDown("up")     then camera:rotate_x(cam_rotate)  end
  if love.keyboard.isDown("down")   then camera:rotate_x(-cam_rotate) end
  if love.keyboard.isDown("return") then camera:rotate_z(cam_rotate)  end
  if love.keyboard.isDown("rshift") then camera:rotate_z(-cam_rotate) end
  
  --move cube
  if love.keyboard.isDown("i") then cube1.y = cube1.y - 300*dt  end
  if love.keyboard.isDown("j") then cube1.x = cube1.x - 300*dt  end
  if love.keyboard.isDown("k") then cube1.y = cube1.y + 300*dt end
  if love.keyboard.isDown("l") then cube1.x = cube1.x + 300*dt end
  
  -- reset
  if love.keyboard.isDown("escape") then
    love.load()
  end
  
  
  -- lets switch up the axis of rotation every certain number of frames for fun
  if framecount % 60 == 0 then
    ax = vect:new(math.random(), math.random(), math.random())
  end
  cube1:rotate_axis(ax, a, speed)
  cube1:update(dt)
  

end


function love.draw()
  -- draw background
  love.graphics.setBackgroundColor(255,255,255,255)
  
  -- draw axis
  draw_axis()
  
  -- draw cube
  cube1:draw()
  
end
















